<?php
function lighthouse_run_blacklist_email( $sanitized_user_login, $user_email, $errors ) {
    global $wpdb;

    // Create the table name
    $table_name = $wpdb->prefix . 'lighthouse_blacklist';

    // Get the domain name and clean it
    [$username, $domain] = explode( '@', $user_email );
    $domain              = esc_sql( strtolower( trim( $domain ) ) );

    // Check the blacklist
    $blacklist_domain = $wpdb->get_results( "SELECT * FROM $table_name WHERE domain LIKE '%$domain%'" );

    if ( ! empty( $blacklist_domain ) || substr_count( $sanitized_user_login, '.' ) > 5 ) {
        $errors->add( 'invalid_email', get_option( 'lighthouse_blacklist_email_message' ) );
    }

    if ( (int) get_option( 'lighthouse_use_external_blacklist' ) === 1 ) {
        // Check external blacklist and get the contents of the txt file
        $ch = curl_init();

        curl_setopt( $ch, CURLOPT_URL, 'https://raw.githubusercontent.com/wolffe/lighthouse-spam-emails/master/blacklist.txt' );
        curl_setopt( $ch, CURLOPT_RETURNTRANSFER, true );
        $blacklist_data = curl_exec( $ch );
        curl_close( $ch );

        // Split the contents into an array of domain names
        $blacklist_domains = explode( "\n", $blacklist_data );
        $blacklist_domains = array_map( 'trim', $blacklist_domains );
        $blacklist_domains = array_filter( $blacklist_domains );

        // Check if the domain matches any of the blacklisted domains
        foreach ( $blacklist_domains as $blacklist_domain ) {
            // Check if the blacklisted domain is a substring of the input domain
            if ( trim( $blacklist_domain ) === $domain || strstr( $domain, trim( $blacklist_domain ) ) !== false ) {
                $errors->add( 'invalid_email', get_option( 'lighthouse_blacklist_email_message' ) );
                break; // Exit the loop if a match is found
            }
        }
        // End external blacklist
    }

    // Increment counter
    $count = get_option( 'lighthouse_spam_registration_count', 0 );
    $count++;
    update_option( 'lighthouse_spam_registration_count', $count );

    return $errors;
}

if ( get_option( 'lighthouse_check_registration_spam' ) === '1' ) {
    //add_filter( 'registration_errors', 'lighthouse_run_blacklist_email', 20, 3 );
    add_filter( 'register_post', 'lighthouse_run_blacklist_email', 20, 3 );
}

// @todo https://plugins.trac.wordpress.org/browser/ban-hammer/trunk/ban-hammer.php#L108
