<form method="post" action="">
    <h2><?php _e( 'Security Settings', 'lighthouse' ); ?></h2>

    <p>Read the <a href="https://wordpress.org/support/article/hardening-wordpress/" rel="external" target="_blank">official WordPress guidelines</a> for hardening and securing your site.</p>

    <table class="form-table">
        <tbody>
            <tr>
                <th scope="row"><label>Basic Security</label></th>
                <td>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_normalize_scheme" value="1" <?php checked( 1, (int) get_option( 'lighthouse_normalize_scheme' ) ); ?>> <span class="lhfr">recommended</span> <label>Normalize HTTP(S) scheme</label><br>
                        <small>Use the scheme/protocol of the current page or do not force a certain scheme (useful when switching from HTTP to HTTPS or to minimize mixed content warnings)</small><br>
                    </p>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_xmlrpc" value="1" <?php checked( 1, (int) get_option( 'lighthouse_xmlrpc' ) ); ?>> <span class="lhfr">recommended</span> <span class="lhfw">use with caution</span> <label>Disable XML-RPC</label><br>
                        <small>Disable remote access to your WordPress site (may cause issues with some plugins)</small>
                    </p>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_disable_rest" value="1" <?php checked( 1, (int) get_option( 'lighthouse_disable_rest' ) ); ?>> <span class="lhfw">use with caution</span> <label>Disallow unauthorized REST requests</label><br>
                        <small>Disallow unauthorized REST API requests (may cause issues with some plugins)</small>
                    </p>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_disable_user_enumeration" value="1" <?php checked( 1, (int) get_option( 'lighthouse_disable_user_enumeration' ) ); ?>> <span class="lhfw">use with caution</span> <label>Disable user enumeration</label><br>
                        <small>Disable user enumeration (may cause issues with some plugins or themes)</small>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row"><label>Brute Force Protection</label></th>
                <td>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_brute_force" value="1" <?php checked( 1, (int) get_option( 'lighthouse_brute_force' ) ); ?>> <span class="lhfr">recommended</span> <span class="lhfw">use with caution</span> <label>Enable brute force protection</label><br>
                        <small>Enabling brute force protection will prevent bots and hackers from attempting to log in to your website with common username and password combinations</small>
                    </p>
                </td>
            </tr>
        </tbody>
    </table>

    <h2>Registration Spam</h2>

    <?php
    $log_file = WP_CONTENT_DIR . '/lighthouse-blacklist.log';

    // Create log file if it doesn't exist
    if ( ! file_exists( $log_file ) ) {
        touch( $log_file );
        chmod( $log_file, 0664 );
    }

    // Read the contents of the log file into an array
    $log_lines = file( $log_file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES );

    // Loop through the array and count the number of times the "restricted" keyword appears
    $restricted_count = 0;
    foreach ( $log_lines as $log_line ) {
        if ( strpos( $log_line, 'restricted' ) !== false ) {
            $restricted_count++;
        }
    }

    // Return the count of restricted registrations
    ?>
    <p>Restricted/spam registrations: <?php echo number_format( get_option( 'lighthouse_spam_registration_count' ) ); ?></p>

    <table class="form-table">
        <tbody>
            <tr>
                <th scope="row"><label>User Registration</label></th>
                <td>
                    <p>
                        <input class="thin-ui-toggle" type="checkbox" name="lighthouse_check_registration_spam" value="1" <?php checked( 1, (int) get_option( 'lighthouse_check_registration_spam' ) ); ?>> <label>Check registration spam</label><br>
                        <small>Prevent users or bots from registering with a disposable or spam email addresses. Only use if you allow public user registration.</small>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row"><label>User Error Message</label></th>
                <td>
                    <p>
                        <textarea name="lighthouse_blacklist_email_message" class="large-text" rows="4"><?php echo get_option( 'lighthouse_blacklist_email_message' ); ?></textarea>
                        <br><small>Custom error message to display when a user tries to register with a blacklisted email address.</small>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label>Blacklisted Words</label>
                </th>
                <td>
                    <p>When a new registration email or username contains any of these words or domains in its content, it will be banned from registration. One word or domain per line. It will match inside words, so ".info" will match all <code>.info</code> domains.</p>
                    <p>
                        <textarea name="blacklist" class="large-text code" rows="8">
<?php
global $wpdb;

$table_name = $wpdb->prefix . 'lighthouse_blacklist';
$record     = $wpdb->get_results( "SELECT * FROM $table_name" );
foreach ( $record as $record ) {
    echo $record->domain . "\r\n";
}
?></textarea>
                    </p>
                </td>
            </tr>
            <tr>
                <th scope="row">
                    <label>Blacklist Providers</label>
                </th>
                <td>
                    <p>
                        <input type="checkbox" class="thin-ui-toggle" id="lighthouse_use_external_blacklist" name="lighthouse_use_external_blacklist" value="1" <?php checked( (int) get_option( 'lighthouse_use_external_blacklist' ), 1 ); ?>>
                        <label for="lighthouse_use_external_blacklist">Use <b>4P</b> external blacklist</label>
                        <br><small><b>4P</b> is the official Lighthouse blacklist. It is updated regularly and contains the most common spam domains.</small>
                    </p>
                </td>
            </tr>
        </tbody>
    </table>

    <hr>
    <p><input type="submit" name="info_security_update" class="button button-primary" value="Save Changes"></p>
</form>
